summaryrefslogtreecommitdiff
path: root/src/mongo/db/repl/oplog.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/db/repl/oplog.h')
-rw-r--r--src/mongo/db/repl/oplog.h8
1 files changed, 5 insertions, 3 deletions
diff --git a/src/mongo/db/repl/oplog.h b/src/mongo/db/repl/oplog.h
index b022aa0e545..e3251102fef 100644
--- a/src/mongo/db/repl/oplog.h
+++ b/src/mongo/db/repl/oplog.h
@@ -128,20 +128,22 @@ void oplogCheckCloseDatabase(OperationContext* txn, Database* db);
/**
* Take a non-command op and apply it locally
* Used for applying from an oplog
* @param convertUpdateToUpsert convert some updates to upserts for idempotency reasons
* Returns failure status if the op was an update that could not be applied.
*/
Status applyOperation_inlock(OperationContext* txn,
Database* db,
const BSONObj& op,
- bool convertUpdateToUpsert = false);
+ bool inSteadyStateReplication = false);
/**
* Take a command op and apply it locally
* Used for applying from an oplog
+ * inSteadyStateReplication indicates whether we are in steady state replication, rather than
+ * initial sync.
* Returns failure status if the op that could not be applied.
*/
-Status applyCommand_inlock(OperationContext* txn, const BSONObj& op);
+Status applyCommand_inlock(OperationContext* txn, const BSONObj& op, bool inSteadyStateReplication);
/**
* Initializes the global Timestamp with the value from the timestamp of the last oplog entry.
@@ -128,20 +128,22 @@ void oplogCheckCloseDatabase(OperationContext* txn, Database* db);
* Take a non-command op and apply it locally
* Used for applying from an oplog
- * @param convertUpdateToUpsert convert some updates to upserts for idempotency reasons
+ * @param inSteadyStateReplication convert some updates to upserts for idempotency reasons
* Returns failure status if the op was an update that could not be applied.
*/